import functools
import pydash.arrays as arrays

def count(gen):
    return functools.reduce(lambda x,y: x + 1, gen, 0)

def flatten(gen):
    for arr in gen:
        for elem in arrays.flatten(arr, is_deep=True):
            yield elem



from functools import wraps
from time import time

def measure_time(name=None):
    def decorator(func):
        called = name if name else func.__name__
        @wraps(func)
        def func_wrapper(*args, **kwargs):
            t0 = time()
            result = func(*args, **kwargs)
            t = time() - t0
            print called, t
            return result
        return func_wrapper
    return decorator


from distutils.core import setup
setup(
  name = 'tdash',
  packages = ['tdash'], # this must be the same as the name above
  version = '0.0.6',
  description = 'Collection of utils inspired by underscore and lodash. No guarantees that I will not change this on a whim',
  author = 'Andrew Jefferson',
  author_email = 'andyj.trinity@gmail.com',
  url = 'https://github.com/eastlondoner/tdash', # use the URL to the github repo
  download_url = 'https://github.com/eastlondoner/tdash/tarball/0.0.6',
  keywords = [], # arbitrary keywords
  classifiers = [],
  install_requires=[
      'pydash',
  ],
)
